# yabs-test
[![Build Status](https://travis-ci.org/mar10/yabs-test.svg?branch=master)](https://travis-ci.org/mar10/yabs-test)
[![Latest Version](https://img.shields.io/pypi/v/yabs-test.svg)](https://pypi.python.org/pypi/yabs-test/)
[![License](https://img.shields.io/pypi/l/yabs-test.svg)](https://github.com/mar10/yabs-test/blob/master/LICENSE.txt)
[![Documentation Status](https://readthedocs.org/projects/yabs-test/badge/?version=latest)](https://yabs-test.readthedocs.io/)
[![Coverage Status](https://coveralls.io/repos/github/mar10/yabs-test/badge.svg?branch=master)](https://coveralls.io/github/mar10/yabs-test?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![StackOverflow: yabs-test](https://img.shields.io/badge/StackOverflow-yabs-blue.svg)](https://stackoverflow.com/questions/tagged/yabs)

Temporary repository and throw-away project to test the
[yabs](https://github.com/mar10/yabs) tool.
